@@ -1,3 +1,4 @@
+# $Id: EditFiles.pm 44375 2007-09-10 14:56:46Z wsnyder $
 # See copyright, etc in below POD section.
 ######################################################################
 
@@ -8,12 +9,12 @@ use File::Path;
 use Carp;
 use strict;
 
-use vars qw($VERSION $Debug);
+use vars qw ($VERSION $Debug);
 
 ######################################################################
 #### Configuration Section
 
-$VERSION = '2.468';
+$VERSION = '3.012';
 
 #######################################################################
 # CONSTRUCTORS
@@ -37,7 +38,6 @@ sub new {
 	@_,
     };
     $self->{verbose} = 1 if $Debug;
-    $self->{debug} = 1 if $Debug;
     bless $self, $class;
     return $self;
 }
@@ -66,6 +66,7 @@ sub _read_split_file {
     my @lines = (@header);
     my $modname;
     my $ever_module;
+    my $line_after_mod;
     my $commented;
     while (defined(my $line = $fh->getline)) {
 	$line =~ s!\r!!mg;
@@ -79,56 +80,34 @@ sub _read_split_file {
 		die "%Error: Unhandled translate comment: $line\n";
 	    }
 	}
-
-	while ($line =~ m!.*?(/\*|//|\*/)!g) {
-	    if (!$commented && $1 eq '//') {
-		last;
-	    } elsif (!$commented && $1 eq '/*') {
-		$commented = 1;
-	    } elsif ($commented && $1 eq '*/') {
+	    
+	(my $l2 = $line) =~ s!//.*$!!;
+	if ($l2 =~ s!.*?\*/!!) {
+	    $commented = 0;
+	}
+	while ($l2 =~ s!.*?/\*!!) {
+	    $commented = 1;
+	    if ($l2 =~ s!.*?\*/!!) {
 		$commented = 0;
 	    }
 	}
-
+	
 	if (!$commented
 	    && $line =~ /^\s*(module|primitive)\s+([A-Za-z0-9_]+)/) {
-	    my $newmodname = $2;
-	    if ($modname) { # Already in a module
-		# Support code like this
-		# `ifdef x
-		#   module x (...)
-		# `else
-		#   module x (...)
-		($newmodname eq $modname)
-		    or die "%Error: $filename:$.: module without previous endmodule\n";
-		print "$basename:$.:  continue module $1\n" if $self->{debug};
-	    } else {
-		$modname = $newmodname;
-		$ever_module = 1;
-		print "$basename:$.:  module $1\n" if $self->{debug};
-		my @afterif;
-		my @oldlines = (@lines);
-		@lines = (@header);
-		# Insert our new header before any `ifdef's or `includes
-		my $gotifdef;
-		foreach my $oline (@oldlines) {
-		    $gotifdef = 1 if $oline =~ /`ifdef\b|`include\b/;
-		    if (!$gotifdef) {
-			push @lines, $oline;
-		    } else{
-			push @afterif, $oline;
-		    }
-		}
-		push @lines, $self->{include_header} if $self->{include_header};
-		push @lines, $self->{timescale_header} if $self->{timescale_header};
-		push @lines, "`celldefine\n" if $self->{celldefine};
-		push @lines, $self->{lint_header} if $self->{lint_header};
-		push @lines, @afterif;
-	    }
+	    !$modname or die "%Error: $filename:$.: module without previous endmodule\n";
+	    $modname = $2;
+	    $line_after_mod = 1;
+	    $ever_module = 1;
+	    print "$basename:$.:  module $1\n" if $Debug;
+	    @lines = (@header);
+	    push @lines, $self->{include_header} if $self->{include_header};
+	    push @lines, $self->{timescale_header} if $self->{timescale_header};
+	    push @lines, "`celldefine\n" if $self->{celldefine};
+	    push @lines, $self->{lint_header} if $self->{lint_header};
 	    push @lines, $line;
 	}
 	elsif (!$commented && $line =~ /^\s*end(module|primitive)\b/) {
-	    print "$basename:$.:  endmodule $modname\n" if $self->{debug};
+	    print "$basename:$.:  endmodule $modname\n" if $Debug;
 	    $modname or die "%Error: $filename:$.: endmodule without previous module\n";
 	    push @lines, $line;
 	    push @lines, "`endcelldefine\n" if $self->{celldefine};
@@ -143,21 +122,16 @@ sub _read_split_file {
 	elsif (!$commented
 	    && $line =~ /^\s*\`timescale\s.*/
 	    && $self->{timescale_removal}) {
-	    # Strip existing timescale
-	}
-	elsif (!$commented
-	       && $line =~ /^\s*\`(end)?celldefine\b/
-	       && $self->{celldefine}) {
-	    # Strip existing celldefine, we'll add a new one
+	    # Strip
 	}
 	else {
 	    push @lines, $line;
 	}
     }
     $fh->close;
-
+    
     if (!$ever_module) {
-	print "$basename:1: No module, must be include file: $basemod\n" if $self->{debug};
+	print "$basename:1: No module, must be include file: $basemod\n" if $Debug;
 	push @lines, @trailer;
 	$self->{_files}{$basemod}{created} = 1;
 	$self->{_files}{$basemod}{modname} = $basemod;
@@ -175,7 +149,7 @@ sub write_files {
     foreach my $file (sort (keys %{$self->{_files}})) {
 	my $fileref = $self->{_files}{$file};
 	next if !$fileref->{created};
-	$self->_write_file($self->{outdir}."/".$fileref->{modname}.$self->{v_suffix}, $fileref);
+	$self->_write_file ($self->{outdir}."/".$fileref->{modname}.$self->{v_suffix}, $fileref);
     }
 }
 
@@ -231,7 +205,7 @@ sub edit_file {
     my $wholefile;
     my $origwholefile;
     {	# Read it
-	my $fh = IO::File->new ("<$params{filename}")
+	my $fh = IO::File->new ("<$params{filename}") 
 	    or croak "%Error: $! $params{filename},";
 	local $/; undef $/;
 	$wholefile = <$fh>;
@@ -247,7 +221,7 @@ sub edit_file {
 	print "  $params{write_filename} (Changed)\n" if $params{verbose};
 	my ($dev,$ino,$mode) = stat($params{write_filename});
 	chmod 0777, $params{filename};
-
+	
 	my $fh = IO::File->new (">$params{write_filename}")
 	    or croak "%Error: $! writing $params{write_filename},";
 	print $fh $wholefile;
@@ -272,12 +246,11 @@ Verilog::EditFiles - Split Verilog modules into separate files.
 See splitmodule command.
 
    use Verilog::EditFiles;
-   my $split = Verilog::EditFiles->new
-       (outdir => "processed_rtl",
-	translate_synthesis => 0,
-	lint_header => undef,
-	celldefine => 1,
-	);
+   my $split = EditFiles->new(outdir => "processed_rtl",
+				translate_synthesis => 0,
+				lint_header => undef,
+				celldefine => 1,
+				);
    $split->read_and_split(glob("inbound_rtl/*.v"));
    $split->write_files();
    $split->edit_file(filename=>"foo", cb => sub { return $_[0]; });
@@ -346,7 +319,7 @@ If true, print what files are being read and written.
 
 =back
 
-=item $self->read_and_split([filenames])
+=item $self->read_and_split ([filenames])
 
 Read from the specified filenames.
 
@@ -378,13 +351,13 @@ write back.  Often the callback will simply perform a search and replace.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<http://www.veripool.com/verilog-perl.html>.
 
-Copyright 2006-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2006-2007 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
-Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
